@@ -91,9 +91,18 @@ class DashboardApp(Dash):
         return [page for item in self._menu for page in item.pages]
 
     def create_navigation_layout(self) -> List[Component]:
-        app_title = [html.Div(className="row app-title", children=[html.P(self.title)])]
+        app_title = html.Div(
+            self.title,
+            className="mx-3 py-4 border-bottom app-title",
+        )
         navigation_items = [item.get_menu_item_layout() for item in self._menu]
-        return app_title + navigation_items
+        navigation = html.Div(
+            className="p-3 sidebar-menu",
+            children=[
+                html.Ul(navigation_items, className="nav flex-column"),
+            ],
+        )
+        return [app_title, navigation]
 
     def create_layout(self) -> Component:
         return get_main_layout(self.create_navigation_layout())
