@@ -6,3 +6,6 @@ DEFAULT_DASHBOARDS_DIR = "dashboards"
 
 # default name of the main file which runs the app
 DEFAULT_RUNSERVER_FILE = "runserver.py"
+
+# default name of the assets folder
+DEFAULT_ASSETS_DIR = "assets"
