@@ -9,7 +9,32 @@ from .config import DEFAULT_DASHBOARDS_DIR
 BASE_APP_CONTENT = """from dash import Dash, Input, Output, html
 
 
-layout = html.H1("Welcome to {dash_name}")
+layout = html.Div(
+    className="page-container",
+    children=[
+        html.Div(
+            className="row page-header gy-6",
+            children=[
+                html.Div(
+                    className="col-3 page-title",
+                    children=[html.Span("< alarm_page title section >")],
+                ),
+                html.Div(
+                    className="col-9", children=["< PLACEHOLDER FOR PAGE FILTERS >"]
+                ),
+            ],
+        ),
+        html.Div(
+            className="row g-4 page-content",
+            children=[
+                html.Div(
+                    className="content-container col-12",
+                    children=["< PLACEHOLDER FOR PAGE CONTENT >"],
+                )
+            ],
+        ),
+    ],
+)
 
 def callbacks(app: Dash):
     @app.callback(
@@ -37,6 +62,7 @@ def start_dash(name: str, dash_dir_path: Path):
     dash_path = dash_dir_path / name
 
     validate_path_does_not_exist(dash_path)
+
     dash_path.mkdir()
 
     init_path = dash_path / "__init__.py"
